@@ -9,8 +9,12 @@
 
 #include "kandroidextras_export.h"
 
+#include <KAndroidExtras/AndroidTypes>
+#include <KAndroidExtras/JniTypeTraits>
+
+#include <QUrl>
+
 class QAndroidJniObject;
-class QUrl;
 
 namespace KAndroidExtras {
 
@@ -24,6 +28,8 @@ namespace Uri
     KANDROIDEXTRAS_EXPORT QUrl toUrl(const QAndroidJniObject &uri);
 }
 
+JNI_DECLARE_CONVERTER(android::net::Uri, QUrl, (Uri::toUrl(value)), (Uri::fromUrl(value)))
+
 }
 
 #endif // KANDROIDEXTRAS_URI_H
